@@ -293,10 +293,12 @@ readDWIdata <- function(gradient, dirlist, format, nslice = NULL, order = NULL,
 setMethod("print", "dtiData",
 function(x){
     cat("  Object of class", class(x),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(x@call)
     cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(x@ngrad, collapse="x"), "\n")
+    ns0 <- length(x@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(x@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", x@source, "\n")
     cat("  Slots                :\n")
     print(slotNames(x))
@@ -305,10 +307,12 @@ function(x){
 setMethod("print", "dtiTensor",
 function(x){
     cat("  Object of class", class(x),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(x@call)
     cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(x@ngrad, collapse="x"), "\n")
+    ns0 <- length(x@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(x@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", x@source, "\n")
     cat("  Slots                :\n")
     print(slotNames(x))
@@ -317,10 +321,12 @@ function(x){
 setMethod("print", "dwiMixtensor",
 function(x){
     cat("  Object of class", class(x),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(x@call)
     cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(x@ngrad, collapse="x"), "\n")
+    ns0 <- length(x@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(x@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", x@source, "\n")
     cat("  Naximal number od mixture components:",max(x@order),"\n") 
     cat("  Slots                :\n")
@@ -330,10 +336,12 @@ function(x){
 setMethod("print", "dwiQball",
 function(x){
     cat("  Object of class", class(x),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(x@call)
     cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(x@ngrad, collapse="x"), "\n")
+    ns0 <- length(x@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(x@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", x@source, "\n")
     cat("  Kind                 :", paste(x@what, collapse="x"), "\n")
     cat("  Order                :", paste(x@order, collapse="x"), "\n")
@@ -344,10 +352,12 @@ function(x){
 setMethod("print","dtiIndices",
 function(x){
     cat("  Object of class", class(x),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(x@call)
     cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(x@ngrad, collapse="x"), "\n")
+    ns0 <- length(x@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(x@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", x@source, "\n")
     cat("  Slots                :\n")
     print(slotNames(x))
@@ -357,10 +367,12 @@ function(x){
 setMethod("print","dwiFiber",
 function(x){
     cat("  Object of class", class(x),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(x@call)
     cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(x@ngrad, collapse="x"), "\n")
+    ns0 <- length(x@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(x@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", x@source, "\n")
     cat("  Minimum FA  :", x@minfa, "\n")
     cat("  Maximum angle :", x@maxangle , "\n")
@@ -372,10 +384,12 @@ function(x){
 setMethod("show", "dtiData",
 function(object){
     cat("  Object of class", class(object),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(object@call)
     cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", object@source, "\n")
     cat("  Slots                :\n")
     print(slotNames(object))
@@ -384,10 +398,12 @@ function(object){
 setMethod("show", "dtiTensor",
 function(object){
     cat("  Object of class", class(object),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(object@call)
     cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", object@source, "\n")
     cat("  Slots                :\n")
     print(slotNames(object))
@@ -396,10 +412,12 @@ function(object){
 setMethod("show", "dwiMixtensor",
 function(object){
     cat("  Object of class", class(object),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(object@call)
     cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", object@source, "\n")
     cat("  Naximal number od mixture components:",max(object@order),"\n") 
     cat("  Slots                :\n")
@@ -409,10 +427,12 @@ function(object){
 setMethod("show", "dtiIndices",
 function(object){
     cat("  Object of class", class(object),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(object@call)
     cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", object@source, "\n")
     cat("  Slots                :\n")
     print(slotNames(object))
@@ -421,10 +441,12 @@ function(object){
 setMethod("show","dwiFiber",
 function(object){
     cat("  Object of class", class(object),"\n")
-    cat("  Generated by calls    :\n")
+    cat("  Generated by calls   :\n")
     print(object@call)
     cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients  :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients  :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Source-Filename      :", object@source, "\n")
     cat("  Minimum FA  :", object@minfa, "\n")
     cat("  Maximum angle :", object@maxangle , "\n")
@@ -440,7 +462,9 @@ function(object, ...){
     print(object@call)
     cat("  Source-Filename       :", object@source, "\n")
     cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients   :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients   :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Voxel extensions      :", paste(object@voxelext, collapse="x"), "\n")
     cat("  Index of S0-Images    :", paste(object@s0ind, collapse="x"), "\n")
     cat("  Quantiles of S0-values:","\n")
@@ -457,7 +481,10 @@ function(object, ...){
     print(object@call)
     cat("  Source-Filename       :", object@source, "\n")
     cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients   :", paste(object@ngrad, collapse="x"), "\n")
+    ngrad <- object@ngrad
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients   :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Voxel extensions      :", paste(object@voxelext, collapse="x"), "\n")
     cat("  Quantiles of S0-values:","\n")
     print(signif(quantile(object@th0,...),3))
@@ -465,6 +492,8 @@ function(object, ...){
     cat("  Voxel in mask         :", paste(sum(object@mask), collapse="x"), "\n")
     cat("  Spatial smoothness    :", paste(signif(object@bw,3), collapse="x"), "\n")
     cat("  mean variance         :", paste(signif(mean(object@sigma[object@mask]),3), collapse="x"), "\n")
+    penBIC <- log(ngrad-ns0)/(ngrad-ns0)*6
+    cat("  BIC         :", paste(signif(mean(log(object@sigma[object@mask]))+penBIC,3), collapse="x"), "\n")
     cat("  hmax                  :", paste(object@hmax, collapse="x"), "\n")
     if(length(object@outlier)>0) cat("  Number of outliers    :", paste(length(object@outlier), collapse="x"), "\n")
     cat("\n")
@@ -477,7 +506,10 @@ function(object, ...){
     print(object@call)
     cat("  Source-Filename       :", object@source, "\n")
     cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients   :", paste(object@ngrad, collapse="x"), "\n")
+    ngrad <- object@ngrad
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients   :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Voxel extensions      :", paste(object@voxelext, collapse="x"), "\n")
     cat("  Quantiles of S0-values:","\n")
     print(signif(quantile(object@th0,...),3))
@@ -485,6 +517,8 @@ function(object, ...){
     cat("  Voxel in mask         :", paste(sum(object@mask), collapse="x"), "\n")
     cat("  Spatial smoothness    :", paste(signif(object@bw,3), collapse="x"), "\n")
     cat("  mean variance         :", paste(signif(mean(object@sigma[object@mask]),3), collapse="x"), "\n")
+    penBIC <- log(ngrad-ns0)/(ngrad-ns0)*(1+2*object@order[object@mask])
+    cat("  BIC         :", paste(signif(mean(log(object@sigma[object@mask])+penBIC),3), collapse="x"), "\n")
     cat("  hmax                  :", paste(object@hmax, collapse="x"), "\n")
     if(length(object@outlier)>0) cat("  Number of outliers    :", paste(length(object@outlier), collapse="x"), "\n")
     nofmc <- table(object@order[object@mask])
@@ -500,16 +534,21 @@ function(object, ...){
     print(object@call)
     cat("  Source-Filename       :", object@source, "\n")
     cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients   :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients   :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Voxel extensions      :", paste(object@voxelext, collapse="x"), "\n")
-    cat("  Kind                 :", paste(object@what, collapse="x"), "\n")
-    cat("  Order                :", paste(object@order, collapse="x"), "\n")
+    cat("  Kind                  :", paste(object@what, collapse="x"), "\n")
+    ord <- object@order
+    cat("  Order                 :", paste(ord, collapse="x"), "\n")
     cat("  Quantiles of S0-values:","\n")
     print(signif(quantile(object@th0,...),3))
     cat("  Mean S0-value         :", paste(z <- signif(mean(object@th0),3),collapse="x"), "\n")
     cat("  Voxel in mask         :", paste(sum(object@mask), collapse="x"), "\n")
     cat("  Spatial smoothness    :", paste(signif(object@bw,3), collapse="x"), "\n")
     cat("  mean variance         :", paste(signif(mean(object@sigma[object@mask]),3), collapse="x"), "\n")
+    penBIC <- log(object@ngrad-ns0)*(ord+1)*(ord+2)/2/(object@ngrad-ns0)
+    cat("  BIC         :", paste(signif(mean(log(object@sigma[object@mask]))+penBIC,3), collapse="x"), "\n")
     cat("  hmax                  :", paste(object@hmax, collapse="x"), "\n")
     if(length(object@outlier)>0) cat("  Number of outliers    :", paste(length(object@outlier), collapse="x"), "\n")
     cat("\n")
@@ -522,7 +561,9 @@ function(object, ...){
     print(object@call)
     cat("  Source-Filename       :", object@source, "\n")
     cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients   :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients   :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Voxel extensions      :", paste(object@voxelext, collapse="x"), "\n")
     cat("  Percentage of zero values      :",paste(signif(mean(object@fa==0)*100,3), "%",collapse="x"), "\n")
     cat("  Quantiles of positive FA-values:","\n")
@@ -541,7 +582,9 @@ function(object){
     print(object@call)
     cat("  Source-Filename       :", object@source, "\n")
     cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
-    cat("  Number of Gradients   :", paste(object@ngrad, collapse="x"), "\n")
+    ns0 <- length(object@s0ind)
+    cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
+    cat("  Number of Gradients   :", paste(object@ngrad-ns0, collapse="x"), "\n")
     cat("  Voxel extensions      :", paste(object@voxelext, collapse="x"), "\n")
     cat("  Minimum FA  :", object@minfa, "\n")
     cat("  Maximum angle :", object@maxangle , "\n")
