@@ -23,9 +23,11 @@ Fibertracking::Fibertracking()
 	this->change_dir = false;
 }
 
-Fibertracking::Fibertracking(Voxel& voxels, int x, int y, int z, double voxelext_x, double voxelext_y, double voxelext_z, double min_anisotropy, double max_angle)
+Fibertracking::Fibertracking(Voxel& voxels_in, int x, int y, int z, double voxelext_x_in, double voxelext_y_in, double voxelext_z_in, double min_anisotropy_in, double max_angle)
 {
-	this->voxels = &voxels;
+//	Rprintf("Fibertracking Konstruktor\n");
+	
+	this->voxels = &voxels_in;
 	
 	this->n_e1 = *(new Vector( 0, 0, 1));
 	this->n_e2 = *(new Vector( 0, 1, 0));
@@ -33,6 +35,8 @@ Fibertracking::Fibertracking(Voxel& voxels, int x, int y, int z, double voxelext
 	this->n_e4 = *(new Vector( 0,-1, 0));
 	this->n_e5 = *(new Vector( 0, 0,-1));
 	this->n_e6 = *(new Vector(-1, 0, 0));
+
+//	Rprintf("Normalenvektoren angelegt\n");
 	
 	dim_x = x;
 	dim_y = y;
@@ -42,11 +46,11 @@ Fibertracking::Fibertracking(Voxel& voxels, int x, int y, int z, double voxelext
 	last_plane_dir = 0;
 	
 	num_fibers = 0;
-	this->voxelext_x = voxelext_x, this->voxelext_y = voxelext_y, this->voxelext_z = voxelext_z;
+	this->voxelext_x = voxelext_x_in, this->voxelext_y = voxelext_y_in, this->voxelext_z = voxelext_z_in;
 	
 	cur_voxel_index = 0;
 	
-	this->min_anisotropy = min_anisotropy;
+	this->min_anisotropy = min_anisotropy_in;
 	
 	intersec_angle = 0.;
 	this->max_intersec_angle = max_angle;
@@ -54,6 +58,8 @@ Fibertracking::Fibertracking(Voxel& voxels, int x, int y, int z, double voxelext
 	this->change_dir = false;
 	
 	allVectors = *new VectorList();
+
+//	Rprintf("Vektorliste angelegt\n");
 }
 
 //Fibertracking::~Fibertracking()
@@ -91,7 +97,7 @@ double* Fibertracking::convertToDouble()
 
 	if (allVectors.getLength() == 0)
 	{
-//		printf("\nAll found fibers are too short to be recognized.\nChoose another region of interest\n\n");
+//		Rprintf("\nAll found fibers are too short to be recognized.\nChoose another region of interest\n\n");
 		
 		return NULL;
 	}
@@ -179,7 +185,7 @@ void Fibertracking::nextVoxel_forward()
 //	int cur_order 	  = voxels[cur_voxel_index].getOrder();
 	int cur_dir_index = voxels[cur_voxel_index].getDir_Index();
 	
-//	printf("forw, %d, %d, %d, %d, %d\n", cur_x, cur_y, cur_z, cur_order, cur_dir_index);
+	// Rprintf("forw, %d, %d, %d, %d, %d\n", cur_x, cur_y, cur_z, cur_order, cur_dir_index);
 	
 	int x = cur_x, y = cur_y, z = cur_z;
 	
@@ -312,6 +318,7 @@ void Fibertracking::nextVoxel_forward()
 	
 	// calculate intersection point	
 	intersection = start_o + ( voxel_d * dSkalar );
+
 	start_o = intersection;
 
 	cur_x = x; cur_y = y; cur_z = z;
@@ -334,22 +341,26 @@ void Fibertracking::nextVoxel_forward()
 			temp = 180-temp;
 		}
 		
-//		printf("angle = %f would be dir_index %d\n", temp, i);
-		
 		if (temp < angles)
 		{
 			angles = temp;
 			dir_index = i;
-		}
+		}		
 	}
 		
 	voxels[cur_voxel_index].setDir_Index(dir_index);
 	
-	vec_product = voxel_d * (voxels[cur_voxel_index].getDirections()[dir_index]);
+	if (voxels[cur_voxel_index].getAnisotropy() > min_anisotropy)
+	{
+	    vec_product = voxel_d * (voxels[cur_voxel_index].getDirections()[dir_index]);
+	    intersec_angle = angles;
+	}
+	else
+	{
+	    intersec_angle = 90.;
+	}
 	
-	intersec_angle = angles;
-	
-//	printf("angle = %f is dir_index %d\n", intersec_angle, dir_index);
+	//Rprintf("angle = %f is dir_index %d\n", intersec_angle, dir_index);
 	
 	last_plane_dir = plane_dir;
 
@@ -364,7 +375,7 @@ void Fibertracking::nextVoxel_backward()
 //	int cur_order 	  = voxels[cur_voxel_index].getOrder();
 	int cur_dir_index = voxels[cur_voxel_index].getDir_Index();
 	
-//	printf("back, %d, %d, %d, %d, %d\n", cur_x, cur_y, cur_z, cur_order, cur_dir_index);
+	// Rprintf("back, %d, %d, %d, %d, %d\n", cur_x, cur_y, cur_z, cur_order, cur_dir_index);
 	
 	int x = cur_x, y = cur_y, z = cur_z;
 	
@@ -520,8 +531,6 @@ void Fibertracking::nextVoxel_backward()
 			temp = 180-temp;
 		}
 		
-//		printf("angle = %f would be dir_index %d\n", temp, i);
-		
 		if (temp < angles)
 		{
 			angles = temp;
@@ -530,12 +539,18 @@ void Fibertracking::nextVoxel_backward()
 	}
 	
 	voxels[cur_voxel_index].setDir_Index(dir_index);
+
+	if (voxels[cur_voxel_index].getAnisotropy() > min_anisotropy)
+	{
+	    vec_product = voxel_d * (voxels[cur_voxel_index].getDirections()[dir_index]);
+	    intersec_angle = angles;
+	}
+	else
+	{
+	    intersec_angle = 90.;
+	}
 	
-	vec_product = voxel_d * (voxels[cur_voxel_index].getDirections()[dir_index]);
-	
-	intersec_angle = angles;
-	
-//	printf("angle = %f is dir_index %d\n", intersec_angle, dir_index);
+//	Rprintf("angle = %f is dir_index %d\n", intersec_angle, dir_index);
 
 	last_plane_dir = plane_dir;
 
@@ -551,13 +566,13 @@ void Fibertracking::trackFiber_forward()
 
 	curVectorList = *new VectorList();
 	
-	while (current->getAnisotropy() >= min_anisotropy && !current->isVisited() && (fabs(intersec_angle) <= max_intersec_angle) )
+	while (current->getAnisotropy() > min_anisotropy && !current->isVisited() && (fabs(intersec_angle) < max_intersec_angle) )
 	{
-//		current->print();
+	  // current->print();
 		
 		currentFiber.add_at_end(*current);
 		
-		curVectorList.add_at_end(start_o);
+		curVectorList.add_at_end(start_o);  // schreibt den Schnittpunkt an die verkettete Liste
 		
 		curVec = new Vector((double)(voxels[cur_voxel_index].getDir_Index()), (double)cur_voxel_index, 0.);
 		curVectorList.add_at_end(*curVec);
@@ -593,9 +608,6 @@ void Fibertracking::trackFiber_forward()
 			}
 		}
 	}
-		
-	last_plane_dir = 0;
-	change_dir = false;
 }
 
 void Fibertracking::trackFiber_backward()
@@ -619,17 +631,18 @@ void Fibertracking::trackFiber_backward()
 		current = &voxels[cur_voxel_index];
 	}
 	
-	while (current->getAnisotropy() >= min_anisotropy && !current->isVisited() && (fabs(intersec_angle) <= max_intersec_angle) )
+	while (current->getAnisotropy() > min_anisotropy && !current->isVisited() && (fabs(intersec_angle) < max_intersec_angle) )
 	{
 //		current->setVisited(true);
 		
 		curVec = new Vector((double)(voxels[cur_voxel_index].getDir_Index()), (double)cur_voxel_index, 0.);
+
 		curVectorList.add_at_start(*curVec);
 
 		curVectorList.add_at_start(start_o);
 		
-		currentFiber.add_at_start(*current);
-		
+		currentFiber.add_at_start(*current);	       
+
 		nextVoxel_backward();
 		
 		if ( current == &voxels[cur_voxel_index])
@@ -661,52 +674,66 @@ void Fibertracking::trackFiber_backward()
 			}
 		}
 	}
-	
-	last_plane_dir = 0;
-	change_dir = false;
 }
 
 void Fibertracking::findAllFibers()
 {
-//	printf("Searching for fibers...\n");
+//	Rprintf("Searching for fibers...\n");
 	
 	while (last_start_voxel < dim_x*dim_y*dim_z)
 	{
-		if (voxels[last_start_voxel].getAnisotropy() >= min_anisotropy && voxels[last_start_voxel].isStartable())
+	        R_CheckUserInterrupt();
+
+		if (voxels[last_start_voxel].getAnisotropy() > min_anisotropy && voxels[last_start_voxel].isStartable())
 		{
-//			num_fibers++;
-//			printf("currentFiber = *new Fiber();\n");
-			currentFiber = *new Fiber();
-//			printf("currentFiber angelegt\n");
-//			printf("curVectorList = *new VectorList();\n");
-			curVectorList = *new VectorList();
-//			printf("curVecotrList angelegt\n");
-			
-//			printf("Fiber found!\n");
-//			printf("============\n");
-			
-			cur_voxel_index = voxels[last_start_voxel].getX() + voxels[last_start_voxel].getY()*dim_x + voxels[last_start_voxel].getZ()*dim_x*dim_y;
-			trackFiber_forward();
-			
-			// Zuruecksetzen von wichtigen Parametern
-			intersec_angle = 0.;
-			cur_voxel_index = voxels[last_start_voxel].getX() + voxels[last_start_voxel].getY()*dim_x + voxels[last_start_voxel].getZ()*dim_x*dim_y;
-			trackFiber_backward();
-			
-			allVectors.add_list(curVectorList);
-			
-			currentFiber.unvisit();
-			
-//			printf("============\n");
-//			printf("Searching continued...\n");
+
+			for (int i = 0; i < voxels[last_start_voxel].getOrder(); i++) 
+			{
+			        num_fibers++;
+
+				currentFiber = *new Fiber();
+				curVectorList = *new VectorList(); 
+				
+//				Rprintf("Fiber found!\n");
+//				Rprintf("============\n");
+	
+				cur_voxel_index = voxels[last_start_voxel].getX() + voxels[last_start_voxel].getY()*dim_x + voxels[last_start_voxel].getZ()*dim_x*dim_y;
+				
+				voxels[cur_voxel_index].setDir_Index(i);
+				
+				trackFiber_forward();
+				
+				// Zuruecksetzen von wichtigen Parametern
+				intersec_angle = 0.;
+				cur_voxel_index = voxels[last_start_voxel].getX() + voxels[last_start_voxel].getY()*dim_x + voxels[last_start_voxel].getZ()*dim_x*dim_y;
+				last_plane_dir = 0;
+				change_dir = false;
+				voxels[cur_voxel_index].setDir_Index(i);
+
+				trackFiber_backward();
+				
+				intersec_angle = 0.;
+				last_plane_dir = 0;
+				change_dir = false;
+				
+				allVectors.add_list(curVectorList);
+				
+				currentFiber.unvisit();
+			}
+
+//			Rprintf("============\n");
+//			Rprintf("Searching continued...\n");
 		}
 		
 		last_start_voxel++;
 	}
 	
-	allVectors.del_at_start();
+	if (allVectors.getLength() != 0)
+	{
+		allVectors.del_at_start();
+	}
 	
-//	printf("End of searching.\n");
+//	Rprintf("End of searching.\n");
 }
 
 void Fibertracking::findMarkedFibers(int* ranges)
@@ -738,19 +765,22 @@ void Fibertracking::findMarkedFibers(int* ranges)
 	
 	while (last_start_voxel < length)
 	{
-		if (marked[last_start_voxel].getAnisotropy() >= min_anisotropy && marked[last_start_voxel].isStartable())
+	        R_CheckUserInterrupt();
+
+		if (marked[last_start_voxel].getAnisotropy() > min_anisotropy && marked[last_start_voxel].isStartable())
 		{
-			num_fibers++;
 
 			for (int i = 0; i < marked[last_start_voxel].getOrder(); i++) 
 			{
+			        num_fibers++;
+
 				currentFiber = *new Fiber();
 				curVectorList = *new VectorList(); 
 				
-//				printf("Fiber found!\n");
-//				printf("============\n");
+//				Rprintf("Fiber found!\n");
+//				Rprintf("============\n");
 	
-				cur_voxel_index = marked[last_start_voxel].getX() + marked[last_start_voxel].getY()*dim_x + marked[last_start_voxel].getZ()*dim_x*dim_y;			
+				cur_voxel_index = marked[last_start_voxel].getX() + marked[last_start_voxel].getY()*dim_x + marked[last_start_voxel].getZ()*dim_x*dim_y;
 				
 				voxels[cur_voxel_index].setDir_Index(i);
 				
@@ -759,17 +789,23 @@ void Fibertracking::findMarkedFibers(int* ranges)
 				// Zuruecksetzen von wichtigen Parametern
 				intersec_angle = 0.;
 				cur_voxel_index = marked[last_start_voxel].getX() + marked[last_start_voxel].getY()*dim_x + marked[last_start_voxel].getZ()*dim_x*dim_y;
+				last_plane_dir = 0;
+				change_dir = false;
+				voxels[cur_voxel_index].setDir_Index(i);
+
 				trackFiber_backward();
 				
 				intersec_angle = 0.;
+				last_plane_dir = 0;
+				change_dir = false;
 				
 				allVectors.add_list(curVectorList);
 				
 				currentFiber.unvisit();
 			}
-			
-//			printf("============\n");
-//			printf("Searching continued...\n");
+
+//			Rprintf("============\n");
+//			Rprintf("Searching continued...\n");
 		}
 		
 		last_start_voxel++;
@@ -780,13 +816,13 @@ void Fibertracking::findMarkedFibers(int* ranges)
 		allVectors.del_at_start();
 	}
 	
-//	printf("End of searching.\n");
+//	Rprintf("End of searching.\n");
 	
 //	double all_abort = n_visited+n_angle+n_aniso+n_border+n_turn;
 
-//	printf("Abort fibers because of:\nvisited\t=\t%d ( %f% )\naniso\t=\t%d ( %f% )\nangle\t=\t%d ( %f% )\nborder\t=\t%d ( %f% )\nturn\t=\t%d ( %f% )\n", n_visited, (double)n_visited*100./all_abort, n_aniso, (double)n_aniso*100./all_abort, n_angle, (double)n_angle*100./all_abort, n_border, (double)n_border*100./all_abort, n_turn, (double)n_turn*100./all_abort);
+//	Rprintf("Abort fibers because of:\nvisited\t=\t%d ( %f% )\naniso\t=\t%d ( %f% )\nangle\t=\t%d ( %f% )\nborder\t=\t%d ( %f% )\nturn\t=\t%d ( %f% )\n", n_visited, (double)n_visited*100./all_abort, n_aniso, (double)n_aniso*100./all_abort, n_angle, (double)n_angle*100./all_abort, n_border, (double)n_border*100./all_abort, n_turn, (double)n_turn*100./all_abort);
 	
-//	printf("num_fibers = %d\n", num_fibers);
+//	Rprintf("num_fibers = %d\n", num_fibers);
 	
 	n_angle = 0;
 	n_visited = 0;
